/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2013 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.security.realms.tools;

import org.sonatype.security.model.Configuration;

/**
 * An abstract class that removes the boiler plate code of reading in the dynamic security configuration.
 * 
 * @author Brian Demers
 */
public abstract class AbstractDynamicSecurityResource
    implements DynamicSecurityResource
{

    protected volatile boolean dirty = true;

    public boolean isDirty()
    {
        return dirty;
    }

    protected void setDirty( boolean dirty )
    {
        this.dirty = dirty;
    }

    protected abstract Configuration doGetConfiguration();

    public Configuration getConfiguration()
    {
        Configuration config = doGetConfiguration();
        // unset the dirty flag
        this.setDirty( false );
        return config;
    }
}
